@@ -12,49 +12,62 @@
 ApplicationAdaptor::ApplicationAdaptor(MainWindow *pMainWid)
     : QDBusAbstractAdaptor(pMainWid)
 {
+    qDebug() << "Entering ApplicationAdaptor constructor.";
     initMember();
 
     m_pMainWindow = pMainWid;
+    qDebug() << "Exiting ApplicationAdaptor constructor.";
 }
 
 //cppcheck 单元测试 wayland下再用
 void ApplicationAdaptor::openFiles(const QStringList &listFiles)
 {
+    qDebug() << "Entering ApplicationAdaptor::openFiles. Files count:" << listFiles.count();
     m_pMainWindow->play(listFiles);
+    qDebug() << "Exiting ApplicationAdaptor::openFiles.";
 }
 
 //cppcheck 单元测试在用
 void ApplicationAdaptor::openFile(const QString &sFile)
 {
+    qDebug() << "Entering ApplicationAdaptor::openFile. File:" << sFile;
     if(sFile.startsWith("UOS_AI")) {
         QString uosAiStr = sFile.mid(6);
         qInfo() << "sFile: " << sFile << " midd: " << uosAiStr;
         funOpenFile(uosAiStr);
+        qDebug() << "Exiting ApplicationAdaptor::openFile after UOS_AI processing.";
         return;
     }
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QRegExp url_re("\\w+://");
     QUrl url;
     if (url_re.indexIn(sFile) == 0) {
+        qDebug() << "File is a URL. Converting to QUrl.";
         url = QUrl(sFile);
     } else {
+        qDebug() << "File is a local path. Converting to QUrl from local file.";
         url = QUrl::fromLocalFile(sFile);
     }
 #else
     QRegularExpression url_re("\\w+://");
     QUrl url;
     if (url_re.match(sFile).capturedStart() == 0) {
+        qDebug() << "File is a URL. Converting to QUrl.";
         url = QUrl(sFile);
     } else {
+        qDebug() << "File is a local path. Converting to QUrl from local file.";
         url = QUrl::fromLocalFile(sFile);
     }
 #endif
     m_pMainWindow->play({url.toString()});
+    qDebug() << "Exiting ApplicationAdaptor::openFile.";
 }
 
 void ApplicationAdaptor::funOpenFile(const QString &sFile)
 {
+    qDebug() << "Entering ApplicationAdaptor::funOpenFile. File:" << sFile;
     if(m_pMainWindow) {
+        qDebug() << "MainWindow pointer is valid.";
         QList<PlayItemInfo> lstItem = m_pMainWindow->playlist()->engine()->playlist().items();
         for (PlayItemInfo info: lstItem) {
             if(QFileInfo(info.mi.filePath).fileName().toLower().contains(sFile.toLower())) {
@@ -63,7 +76,10 @@ void ApplicationAdaptor::funOpenFile(const QString &sFile)
                 break;
             }
         }
+    } else {
+        qDebug() << "MainWindow pointer is null. Cannot open file.";
     }
+    qDebug() << "Exiting ApplicationAdaptor::funOpenFile.";
 }
 
 void ApplicationAdaptor::Raise()
@@ -72,15 +88,20 @@ void ApplicationAdaptor::Raise()
     m_pMainWindow->showNormal();
     m_pMainWindow->raise();
     m_pMainWindow->activateWindow();
+    qDebug() << "Exiting ApplicationAdaptor::Raise.";
 }
 
 void ApplicationAdaptor::initMember()
 {
+    qDebug() << "Entering ApplicationAdaptor::initMember.";
     m_pMainWindow = nullptr;
+    qDebug() << "Exiting ApplicationAdaptor::initMember.";
 }
 
 QVariant ApplicationAdaptor::redDBusProperty(const QString &sService, const QString &sPath, const QString &sInterface, const char *pPropert)
 {
+    qDebug() << "Entering ApplicationAdaptor::redDBusProperty.";
+    qDebug() << "Service:" << sService << ", Path:" << sPath << ", Interface:" << sInterface << ", Property:" << pPropert;
     // 创建QDBusInterface接口
     QDBusInterface ainterface(sService, sPath,
                               sInterface,
@@ -88,17 +109,21 @@ QVariant ApplicationAdaptor::redDBusProperty(const QString &sService, const QStr
     if (!ainterface.isValid()) {
         qInfo() << qPrintable(QDBusConnection::sessionBus().lastError().message());
         QVariant v(0) ;
+        qDebug() << "Exiting ApplicationAdaptor::redDBusProperty with invalid interface.";
         return  v;
     }
     // 调用远程的value方法
     QList<QByteArray> q = ainterface.dynamicPropertyNames();
     QVariant v = ainterface.property(pPropert);
+    qDebug() << "Exiting ApplicationAdaptor::redDBusProperty. Property value:" << v;
     return  v;
 }
 
 //cppcheck 单元测试在使用
 QVariant ApplicationAdaptor::redDBusMethod(const QString &sService, const QString &sPath, const QString &sInterface, const char *pMethod)
 {
+    qDebug() << "Entering ApplicationAdaptor::redDBusMethod.";
+    qDebug() << "Service:" << sService << ", Path:" << sPath << ", Interface:" << sInterface << ", Method:" << pMethod;
     // 创建QDBusInterface接口
     QDBusInterface ainterface(sService, sPath,
                               sInterface,
@@ -106,6 +131,7 @@ QVariant ApplicationAdaptor::redDBusMethod(const QString &sService, const QStrin
     if (!ainterface.isValid()) {
         qInfo() <<  "error:" << qPrintable(QDBusConnection::sessionBus().lastError().message());
         QVariant v(0) ;
+        qDebug() << "Exiting ApplicationAdaptor::redDBusMethod with invalid interface.";
         return  v;
     }
     // 调用远程的value方法
@@ -116,6 +142,7 @@ QVariant ApplicationAdaptor::redDBusMethod(const QString &sService, const QStrin
     } else {
         qInfo() << "error1:" << qPrintable(QDBusConnection::sessionBus().lastError().message());
         QVariant v(0) ;
+        qDebug() << "Exiting ApplicationAdaptor::redDBusMethod with failed method call.";
         return  v;
     }
 }
