@@ -7,14 +7,17 @@
 #include "filefilter.h"
 #include <player_engine.h>
 #include <compositing_manager.h>
+#include <QDebug>
 
 namespace dmr {
 
 PlayerWidget::PlayerWidget(QWidget *parent)
     : QWidget (parent)
 {
+    qDebug() << "Entering PlayerWidget::PlayerWidget() constructor.";
     auto forceBind = parent ? parent->property("forceBind") : QVariant(false);
     if (forceBind.isValid() && forceBind.toBool()) {
+        qDebug() << "forceBind is valid and true, setting CompositingManager property.";
         CompositingManager::get().setProperty("forceBind", true);
     }
     utils::first_check_wayland_env();
@@ -23,10 +26,13 @@ PlayerWidget::PlayerWidget(QWidget *parent)
     l->setContentsMargins(0, 0, 0, 0);
     l->addWidget(_engine);
     setLayout(l);
+    qDebug() << "Exiting PlayerWidget::PlayerWidget() constructor.";
 }
 
 PlayerWidget::~PlayerWidget()
 {
+    qDebug() << "Entering PlayerWidget::~PlayerWidget() destructor.";
+    qDebug() << "Exiting PlayerWidget::~PlayerWidget() destructor.";
 }
 
 PlayerEngine &PlayerWidget::engine()
@@ -36,16 +42,22 @@ PlayerEngine &PlayerWidget::engine()
 
 void PlayerWidget::play(const QUrl &url)
 {
+    qDebug() << "Entering PlayerWidget::play() with URL:" << url.toString();
     QUrl realUrl;
     realUrl = FileFilter::instance()->fileTransfer(url.toString());
+    qDebug() << "Transferred URL to realUrl:" << realUrl.toString();
 
-    if (!realUrl.isValid())
+    if (!realUrl.isValid()) {
+        qDebug() << "Real URL is not valid, returning.";
         return;
+    }
 
     if (!_engine->addPlayFile(realUrl)) {
+        qDebug() << "Failed to add play file to engine, returning.";
         return;
     }
     _engine->playByName(realUrl);
+    qDebug() << "Exiting PlayerWidget::play().";
 }
 
 }
