@@ -32,8 +32,10 @@ public:
 protected:
     bool eventFilter(QObject *obj, QEvent *event)
     {
+        qDebug() << "PlayItemTooltipHandler eventFilter";
         switch (event->type()) {
         case QEvent::ToolTip: {
+            qDebug() << "ToolTip";
             QHelpEvent *he = static_cast<QHelpEvent *>(event);
             Tip *tip = obj->property("HintWidget").value<Tip *>();
             QWidget *item = tip->property("for").value<QWidget *>();
@@ -52,6 +54,7 @@ protected:
             int dw = QGuiApplication::primaryScreen()->availableGeometry().width();
 #endif
             if (pos.x() + tip->width() > dw) {
+                qDebug() << "Tip width" << tip->width();
                 pos.rx() = dw - tip->width();
             }
             tip->move(pos);
@@ -59,6 +62,7 @@ protected:
         }
 
         case QEvent::Leave: {
+            qDebug() << "Leave";
             auto tip = obj->property("HintWidget").value<Tip *>();
             tip->hide();
             event->ignore();
@@ -86,6 +90,7 @@ public:
     Platform_PlayItemWidget(const PlayItemInfo &pif, QListWidget *list = nullptr, int index = 0, Platform_PlaylistWidget *parent = nullptr)
         : QFrame(), _pif {pif}, _listWidget {list}, _playlist{parent}
     {
+        qDebug() << "PlayItemWidget constructor";
         _thumb = nullptr;
         m_pSvgWidget = nullptr;
         setProperty("PlayItemThumb", "true");
@@ -95,8 +100,10 @@ public:
         auto kd = "local";
         if (!_pif.url.isLocalFile()) {
             if (_pif.url.scheme().startsWith("dvd")) {
+                qDebug() << "dvd";
                 kd = "dvd";
             } else {
+                qDebug() << "network";
                 kd = "network";
             }
         }
@@ -119,23 +126,31 @@ public:
         l->addWidget(_index);
 
         if (_pif.thumbnail.isNull() && _pif.thumbnail_dark.isNull()) {
+            qDebug() << "no thumbnail";
             if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                qDebug() << "dark theme";
                 m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-dark.svg"), this);
             } else {
+                qDebug() << "light theme";
                 m_pSvgWidget = new QSvgWidget(QString(":/resources/icons/music-light.svg"), this);
             }
             m_pSvgWidget->setFixedSize(42, 24);
         } else {
+            qDebug() << "has thumbnail";
             if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                qDebug() << "dark theme";
                 _thumb = new Platform_ListPic(_pif.thumbnail_dark.scaled(QSize(42, 24)), this);
             } else {
+                qDebug() << "light theme";
                 _thumb = new Platform_ListPic(_pif.thumbnail.scaled(QSize(42, 24)), this);
             }
         }
 
         if (_thumb) {
+            qDebug() << "has thumbnail, add to layout";
             l->addWidget(_thumb);
         } else {
+            qDebug() << "no thumbnail, add to layout";
             l->addWidget(m_pSvgWidget);
         }
         QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &Platform_PlayItemWidget::slotThemeTypeChanged);
@@ -205,6 +220,7 @@ public:
         setState(ItemState::Normal);
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        qDebug() << "compact mode";
         setFixedHeight(24);
         _closeBtn->setIconSize(QSize(18, 18));
         _closeBtn->setFixedSize(17, 17);
@@ -217,6 +233,7 @@ public:
 
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
         if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            qDebug() << "normal mode";
             setFixedHeight(36);
             _closeBtn->setIconSize(QSize(28, 28));
             _closeBtn->setFixedSize(25, 25);
@@ -226,6 +243,7 @@ public:
             else
                 m_pSvgWidget->setFixedSize(42, 24);
         } else {
+            qDebug() << "compact mode";
             setFixedHeight(24);
             _closeBtn->setIconSize(QSize(18, 18));
             _closeBtn->setFixedSize(17, 17);
@@ -238,16 +256,20 @@ public:
         updateClosePosition();
     });
 #endif
+    qDebug() << "PlayItemWidget constructor";
     }
     
     ~Platform_PlayItemWidget() override
     {
+        qDebug() << "PlayItemWidget destructor";
         if (m_pSvgWidget) {
+            qDebug() << "delete m_pSvgWidget";
             delete  m_pSvgWidget;
             m_pSvgWidget = nullptr;
         }
 
         if (_thumb) {
+            qDebug() << "delete _thumb";
             delete _thumb;
             _thumb = nullptr;
         }
@@ -255,12 +277,14 @@ public:
 
     void updateInfo(const PlayItemInfo &pif)
     {
+        qDebug() << "updateInfo";
         _pif = pif;
         _time->setText(_pif.mi.durationStr());
         setToolTip(_pif.mi.title);
         updateNameText();
 
         if (!_pif.valid) {
+            qDebug() << "invalid";
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
@@ -269,6 +293,7 @@ public:
 
     void setState(ItemState is)
     {
+        qDebug() << "setState" << is;
         setProperty("ItemState", is);
         updateForeground();
     }
@@ -279,11 +304,13 @@ public:
     }
     void setIndex(int index)
     {
+        qDebug() << "setIndex" << index;
         _index->setText(QString::number(index + 1));
     }
 
     void setHovered(bool v)
     {
+        qDebug() << "setHovered" << v;
         if (_hovered != v) {
             _hovered = v;
             setProperty("hovered", v);
@@ -292,20 +319,24 @@ public:
 
     void setCurItemHovered(bool v)
     {
+        qDebug() << "setCurItemHovered" << v;
         if (_hovered != v) {
             _hovered = v;
             setProperty("hovered", v);
         }
 
         if (v) {
+            qDebug() << "show close button";
             _closeBtn->show();
             _closeBtn->raise();
         } else {
+            qDebug() << "hide close button";
             _closeBtn->hide();
         }
 
         updateClosePosition();
         update();
+        qDebug() << "setCurItemHovered end";
     }
 
     bool getBIsSelect() const
@@ -315,6 +346,7 @@ public:
 
     void setBIsSelect(bool bIsSelect)
     {
+        qDebug() << "setBIsSelect" << bIsSelect;
         m_bIsSelect = bIsSelect;
 
         updateForeground();
@@ -322,20 +354,25 @@ public:
 
     void doDoubleClick()
     {
+        qDebug() << "doDoubleClick";
         //FIXME: there is an potential inconsistency with model if pif did changed
         //(i.e gets deleted).
         _pif.refresh();
         _time->setText(_pif.mi.durationStr());
         if (!_pif.valid) {
+            qDebug() << "invalid";
             setState(ItemState::Invalid);
             _time->setText(tr("The file does not exist"));
         }
         if (!_pif.url.isLocalFile() || _pif.info.exists()) {
+            qDebug() << "local file or exists";
             emit doubleClicked();
         }else{
+            qDebug() << "not local file or not exists";
             //fixed:影院循环播放10个smb上的视频一段时间后，点击播放按钮或点击列表中的视频没反应
             emit _playlist->engine()->sigInvalidFile(QFileInfo(_pif.url.toLocalFile()).fileName());
         }
+        qDebug() << "doDoubleClick end";
     }
 
 signals:
@@ -345,8 +382,10 @@ signals:
 private slots:
     void slotThemeTypeChanged()
     {
+        qDebug() << "slotThemeTypeChanged";
 //        QPalette pa;
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+            qDebug() << "light theme";
             if (_thumb) {
                 _thumb->setPic(_pif.thumbnail);
             } else {
@@ -358,6 +397,7 @@ private slots:
             updateForeground();
         };
         if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+            qDebug() << "dark theme";
             if (_thumb) {
                 _thumb->setPic(_pif.thumbnail_dark);
             } else {
@@ -371,21 +411,25 @@ private slots:
     }
     void slotSizeChange()
     {
+        qDebug() << "slotSizeChange";
         setFixedWidth(_playlist->width() - 230);
     }
 
 protected:
     void updateClosePosition()
     {
+        qDebug() << "updateClosePosition";
         auto margin = 10;
         _closeBtn->move(width() - _closeBtn->width() - margin,
                         (height() - _closeBtn->height()) / 2);
     }
     void updateForeground()
     {
+        qDebug() << "updateForeground";
         m_highlightColor = Dtk::Gui::DGuiApplicationHelper::instance()->applicationPalette().highlight().color();
 
         if(m_bIsSelect) {
+            qDebug() << "selected";
             _name->setForegroundRole(DPalette::Text);
             _index->setForegroundRole(DPalette::Text);
 
@@ -395,21 +439,26 @@ protected:
             _index->setPalette(pa);
             update();
         } else {
+            qDebug() << "not selected";
             if (state() == ItemState::Playing) {
+                qDebug() << "playing";
                 _name->setForegroundRole(DPalette::Highlight);
                 _index->setForegroundRole(DPalette::Highlight);
                 _time->setForegroundRole(DPalette::Highlight);
             } else {
+                qDebug() << "not playing";
                 _name->setForegroundRole(DPalette::BrightText);
                 _index->setForegroundRole(DPalette::BrightText);
                 _time->setForegroundRole(DPalette::BrightText);
 
                 QPalette pa;
                 if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+                    qDebug() << "light theme";
                     pa.setColor(QPalette::BrightText, Qt::black);
                     _name->setPalette(pa);
                     _index->setPalette(pa);
                 } else if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+                    qDebug() << "dark theme";
                     pa.setColor(QPalette::BrightText, Qt::white);
                     _name->setPalette(pa);
                     _index->setPalette(pa);
@@ -419,6 +468,7 @@ protected:
     }
     void leaveEvent(QEvent *e) override
     {
+        qDebug() << "leaveEvent";
         _closeBtn->hide();
         setHovered(false);
 
@@ -427,6 +477,7 @@ protected:
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEvent *e) override
     {
+        qDebug() << "Qt5 enterEvent";
         _closeBtn->show();
         _closeBtn->raise();
 
@@ -438,6 +489,7 @@ protected:
 #else
     void enterEvent(QEnterEvent *e) override
     {
+        qDebug() << "Qt6 enterEvent";
         _closeBtn->show();
         _closeBtn->raise();
 
@@ -451,12 +503,14 @@ protected:
     {
         if (e->type() == QEvent::MouseButtonDblClick) {
             doDoubleClick();
+            qDebug() << "MouseButtonDblClick return";
             return true;
         }
         return QWidget::eventFilter(obj, e);
     }
     void resizeEvent(QResizeEvent *re) override
     {
+        qDebug() << "resizeEvent";
         updateClosePosition();
         _name->setFixedWidth(width() - 180);
         updateNameText();
@@ -465,24 +519,29 @@ protected:
     }
     bool event(QEvent *ee) override
     {
+        qDebug() << "event" << ee->type();
         if (ee->type() == QEvent::Move) {
+            qDebug() << "Move";
         }
 
         return QFrame::event(ee);
     }
     void updateNameText()
     {
+        qDebug() << "updateNameText";
         _name->setText(utils::ElideText(_pif.mi.title, {width() - 242, 36}, QTextOption::NoWrap,
                                         _name->font(), Qt::ElideRight, 18, width() - 242));
         _name->setCursor(Qt::ArrowCursor);
     }
     void showEvent(QShowEvent *se) override
     {
+        qDebug() << "showEvent";
         updateNameText();
         QFrame::showEvent(se);
     }
     void mouseDoubleClickEvent(QMouseEvent *me) override
     {
+        qDebug() << "mouseDoubleClickEvent";
         doDoubleClick();
 
         QFrame::mouseDoubleClickEvent(me);
@@ -533,6 +592,7 @@ protected:
         }
 
         if (m_bIsSelect) {
+            qDebug() << "m_bIsSelect";
             _time->hide();
             _closeBtn->show();
             _closeBtn->raise();
@@ -540,9 +600,10 @@ protected:
             pp.addRoundedRect(bgRect, 8, 8);
             painter.fillPath(pp, m_highlightColor);
         } else {
-        _time->show();
-        _closeBtn->hide();
-    }
+            qDebug() << "not m_bIsSelect";
+            _time->show();
+            _closeBtn->hide();
+        }
         QFrame::paintEvent(pe);
     }
 
@@ -574,9 +635,11 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event)
     {
         if (event->type() == QEvent::MouseButtonPress) {
+            qDebug() << "MouseButtonPress";
             QMouseEvent *me = static_cast<QMouseEvent *>(event);
 
             if (me->buttons() == Qt::LeftButton) {
+                qDebug() << "LeftButton";
                 if (!m_bClicked) {
                     m_bClicked = true;
                     m_lastPoint = me->globalPos();
@@ -592,6 +655,7 @@ protected:
                         if (mw->insideResizeArea(m_lastPoint))
                             return;
                         if (plw->state() == Platform_PlaylistWidget::Opened && !plw->underMouse()) {
+                            qDebug() << "TogglePlaylist";
                             mw->requestAction(ActionFactory::ActionKind::TogglePlaylist);
                         }
                     });
@@ -599,6 +663,7 @@ protected:
             }
             return false;
         } else if (event->type() == QEvent::MouseButtonDblClick) {
+            qDebug() << "MouseButtonDblClick";
             m_bClicked = false;
             return QObject::eventFilter(obj, event);
         }/* else if (event->type() == QEvent::KeyRelease) { //这段代码会导致Enter播放列表后，播放列表关闭
@@ -620,6 +685,7 @@ protected:
             }
             return false;
         }*/ else {
+            qDebug() << "standard event processing";
             // standard event processing
             return QObject::eventFilter(obj, event);
         }
@@ -646,12 +712,15 @@ public:
 protected:
     bool eventFilter(QObject *obj, QEvent *event)
     {
+        qDebug() << "Platform_MouseEventListener eventFilter";
         if (event->type() == QEvent::MouseButtonPress) {
             QMouseEvent *pMouseEvent = static_cast<QMouseEvent *>(event);
             if (pMouseEvent->buttons() == Qt::LeftButton && !m_pListWidget->itemAt(pMouseEvent->pos())) {
+                qDebug() << "LeftButton";
                 Platform_PlayItemWidget *pItem = reinterpret_cast<Platform_PlayItemWidget *>(m_pListWidget->itemWidget(m_pListWidget->currentItem()));
                 if(pItem)
                 {
+                    qDebug() << "setBIsSelect false";
                     pItem->setBIsSelect(false); // 点击播放列表空白处，取消item选中效果
                     m_pListWidget->update();
                 }
@@ -667,7 +736,9 @@ private:
 Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     : QWidget(mw), _engine(mpv), _mw(static_cast<Platform_MainWindow *>(mw))
 {
+    qDebug() << "Initializing Platform_PlaylistWidget";
     bool composited = CompositingManager::get().composited();
+    qDebug() << "Composited mode:" << composited;
     setAttribute(Qt::WA_TranslucentBackground, false);
     this->setObjectName(PLAYLIST_WIDGET);
 
@@ -739,9 +810,11 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     DPalette pa_cb = DGuiApplicationHelper::instance()->applicationPalette();
 #endif
     if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+        qDebug() << "light theme";
         pa_cb.setBrush(QPalette::Light, QColor(100, 100, 100, 255));
         pa_cb.setBrush(QPalette::Dark, QColor(92, 92, 92, 255));
     } else {
+        qDebug() << "dark theme";
         pa_cb.setBrush(QPalette::Light, QColor(85, 84, 84, 255));
         pa_cb.setBrush(QPalette::Dark, QColor(65, 65, 65, 255));
     }
@@ -757,9 +830,11 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
         DPalette pa_cBtn = DGuiApplicationHelper::instance()->applicationPalette();
 #endif
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+            qDebug() << "light theme";
             pa_cBtn.setBrush(QPalette::Light, QColor(100, 100, 100, 255));
             pa_cBtn.setBrush(QPalette::Dark, QColor(92, 92, 92, 255));
         } else {
+            qDebug() << "dark theme";
             pa_cBtn.setBrush(QPalette::Light, QColor(85, 84, 84, 255));
             pa_cBtn.setBrush(QPalette::Dark, QColor(65, 65, 65, 255));
         }
@@ -815,6 +890,7 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     _playlist->setContentsMargins(0, 0, 0, 0);
 
     if (!composited) {
+        qDebug() << "Setting non-composited window flags";
         _playlist->setWindowFlags(Qt::FramelessWindowHint | Qt::BypassWindowManagerHint);
         _playlist->setAttribute(Qt::WA_NativeWindow);
     }
@@ -827,6 +903,7 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
 #endif
 
     if (!_closeMapper) {
+        qDebug() << "create closeMapper";
         _closeMapper = new QSignalMapper(this);
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         connect(_closeMapper,
@@ -841,6 +918,7 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     }
 
     if (!_activateMapper) {
+        qDebug() << "create activateMapper";
         _activateMapper = new QSignalMapper(this);
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         connect(_activateMapper,
@@ -856,12 +934,15 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        qDebug() << "sizeModeChanged" << sizeMode;
         if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            qDebug() << "NormalMode";
             for (int i = 0; i < _playlist->count(); i++) {
                 QListWidgetItem *item = _playlist->item(i);
                 item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 36));
             }
         } else {
+            qDebug() << "CompactMode";
             for (int i = 0; i < _playlist->count(); i++) {
                 QListWidgetItem *item = _playlist->item(i);
                 item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 24));
@@ -894,6 +975,7 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
     });
 
     connect(_playlist->model(), &QAbstractItemModel::rowsMoved, this, &Platform_PlaylistWidget::slotRowsMoved);
+    qDebug() << "Playlist widget created";
 }
 
 Platform_PlaylistWidget::~Platform_PlaylistWidget()
@@ -902,26 +984,30 @@ Platform_PlaylistWidget::~Platform_PlaylistWidget()
 
 void Platform_PlaylistWidget::updateSelectItem(const int key)
 {
+    qDebug() << "Updating selected item with key:" << key;
     auto curItem = _playlist->currentItem();
     auto curRow = _playlist->row(curItem);
-    qInfo() << "prevRow..." << curRow;
+    qDebug() << "Current row:" << curRow;
+    
     Platform_PlayItemWidget *prevItemWgt = nullptr;
     if (curItem) {
         prevItemWgt = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(curItem));
     }
 
     if (key == Qt::Key_Up) {
+        qDebug() << "Handling Key_Up";
         if (curRow == -1) {
             _index = curRow + 1;
         } else {
             _index = curRow - 1;
         }
         if (_index < 0) {
+            qDebug() << "Index out of bounds, returning";
             return;
         }
 
         _playlist->setCurrentRow(_index);
-        qInfo() << "Enter Key_Up..." << _index;
+        qDebug() << "New index after Key_Up:" << _index;
         auto curItemWgt = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(_playlist->item(_index)));
         if (prevItemWgt) {
             prevItemWgt->setBIsSelect(false);
@@ -931,12 +1017,14 @@ void Platform_PlaylistWidget::updateSelectItem(const int key)
         }
 
     } else if (key == Qt::Key_Down) {
+        qDebug() << "Handling Key_Down";
         if (_index >= _playlist->count() - 1) {
+            qDebug() << "Already at last item, returning";
             return;
         }
         _index = curRow + 1;
         _playlist->setCurrentRow(_index);
-        qInfo() << "Enter Key_Down..." << _index;
+        qDebug() << "New index after Key_Down:" << _index;
         auto curItemWgt = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(_playlist->item(_index)));
         if (prevItemWgt) {
             prevItemWgt->setBIsSelect(false);
@@ -945,9 +1033,12 @@ void Platform_PlaylistWidget::updateSelectItem(const int key)
             curItemWgt->setBIsSelect(true);
         }
     } else if (key == Qt::Key_Enter || key == Qt::Key_Return) {
+        qDebug() << "Handling Enter/Return key";
         if (m_pClearButton == focusWidget()) {   //focus在清空按钮上则清空列表
+            qDebug() << "Clear button focused, clearing playlist";
             _engine->clearPlaylist();
         } else {
+            qDebug() << "Playing selected item";
             slotDoubleClickedItem(prevItemWgt);  //Enter键播放
         }
     }
@@ -955,6 +1046,7 @@ void Platform_PlaylistWidget::updateSelectItem(const int key)
 
 void Platform_PlaylistWidget::clear()
 {
+    qDebug() << "Clearing playlist";
     _playlist->clear();
     QString s = QString(tr("%1 videos")).arg(_playlist->count());
     _num->setText(s);
@@ -963,15 +1055,18 @@ void Platform_PlaylistWidget::clear()
 
 void Platform_PlaylistWidget::updateItemInfo(int id)
 {
+    qDebug() << "Updating item info for id:" << id;
     auto piw = dynamic_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(_playlist->item(id)));
-    if (piw == nullptr)     //update info thx
-        return ;
+    if (piw == nullptr) {
+        qWarning() << "Failed to get item widget for id:" << id;
+        return;
+    }
     piw->updateInfo(_engine->playlist().items()[id]);
 }
 
 void Platform_PlaylistWidget::updateItemStates()
 {
-    qInfo() << __func__ << _playlist->count() << "current = " << _engine->playlist().current();
+    qDebug() << "Updating item states, count:" << _playlist->count() << "current:" << _engine->playlist().current();
 
     for (int i = 0; i < _playlist->count(); i++) {
         auto piw = dynamic_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(_playlist->item(i)));
@@ -979,16 +1074,15 @@ void Platform_PlaylistWidget::updateItemStates()
         auto old = piw->state();
         piw->setState(ItemState::Normal);
         if (!piw->_pif.valid) {
+            qDebug() << "Item" << i << "is invalid";
             piw->setState(ItemState::Invalid);
         }
 
         if (i == _engine->playlist().current()) {
             if (piw->state() != ItemState::Playing) {
-                //scrollToItem只能更新scroll位置，不能同步列表项
-                //_playlist->scrollToItem(_playlist->item(i));
+                qDebug() << "Setting item" << i << "as playing";
                 _playlist->setCurrentRow(i);
                 piw->setState(ItemState::Playing);
-
             }
         }
     }
@@ -996,9 +1090,14 @@ void Platform_PlaylistWidget::updateItemStates()
 
 void Platform_PlaylistWidget::showItemInfo()
 {
-    if (!_mouseItem) return;
+    qDebug() << "showItemInfo";
+    if (!_mouseItem) {
+        qDebug() << "No mouse item, returning";
+        return;
+    }
     auto item = dynamic_cast<Platform_PlayItemWidget *>(_mouseItem);
     if (item) {
+        qDebug() << "Mouse item is valid";
         MovieInfoDialog mid(item->_pif, _mw);
         mid.exec();
     }
@@ -1006,21 +1105,29 @@ void Platform_PlaylistWidget::showItemInfo()
 
 void Platform_PlaylistWidget::openItemInFM()
 {
-    if (!_mouseItem) return;
+    qDebug() << "openItemInFM";
+    if (!_mouseItem) {
+        qDebug() << "No mouse item, returning";
+        return;
+    }
     auto item = dynamic_cast<Platform_PlayItemWidget *>(_mouseItem);
     if (item) {
+        qDebug() << "Mouse item is valid, opening in file manager";
         utils::ShowInFileManager(item->_pif.mi.filePath);
     }
 }
 
 void Platform_PlaylistWidget::removeClickedItem(bool isShortcut)
 {
+    qDebug() << "removeClickedItem";
     if (isShortcut && isVisible()) {
+        qDebug() << "Shortcut and visible, removing item";
         for (int i = 0; i < _playlist->count(); i++) {
             Platform_PlayItemWidget * piw = dynamic_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(_playlist->item(i)));
             qInfo() << piw->getBIsSelect();
             if (piw->getBIsSelect()) {
                 _engine->playlist().remove(i);
+                qInfo() << "Item removed";
                 return;
             }
         }
@@ -1037,10 +1144,12 @@ void Platform_PlaylistWidget::removeClickedItem(bool isShortcut)
             }
         }
     }
+    qInfo() << "Clicked item removed";
 }
 
 void Platform_PlaylistWidget::slotCloseTimeTimeOut()
 {
+    qDebug() << "slotCloseTimeTimeOut";
     QTimer *pCloselistTimer = dynamic_cast<QTimer *>(sender());
     pCloselistTimer->deleteLater();
     togglePopup(false);
@@ -1049,7 +1158,7 @@ void Platform_PlaylistWidget::slotCloseTimeTimeOut()
 
 void Platform_PlaylistWidget::slotCloseItem(QWidget *w)
 {
-    qInfo() << "item close clicked";
+    qDebug() << "item close clicked";
     _clickedItem = w;
     _mw->requestAction(ActionFactory::ActionKind::PlaylistRemoveItem);
 }
@@ -1074,6 +1183,7 @@ void Platform_PlaylistWidget::slotDoubleClickedItem(QWidget *w)
 
 void Platform_PlaylistWidget::slotRowsMoved()
 {
+    qDebug() << "slotRowsMoved";
     if (_lastDragged.first >= 0) {
         int target = -1;
         for (int i = 0; i < _playlist->count(); i++) {
@@ -1085,6 +1195,7 @@ void Platform_PlaylistWidget::slotRowsMoved()
         }
         qInfo() << "swap " << _lastDragged.first << target;
         if (target >= 0 && _lastDragged.first != target) {
+            qInfo() << "swap " << _lastDragged.first << target;
             _engine->playlist().switchPosition(_lastDragged.first, target);
             _lastDragged = {-1, nullptr};
         }
@@ -1157,23 +1268,28 @@ void Platform_PlaylistWidget::slotRowsMoved()
 
 void Platform_PlaylistWidget::contextMenuEvent(QContextMenuEvent *cme)
 {
+    qDebug() << "contextMenuEvent";
     bool on_item = false;
     _mouseItem = nullptr;
     QPoint itempos(cme->pos().x() - 235, cme->pos().y() - 20);
 
     if (_playlist->itemAt(itempos)) {
+        qDebug() << "itemAt";
         _mouseItem = _playlist->itemWidget(_playlist->itemAt(itempos));
         on_item = true;
     }
 
     if (CompositingManager::get().isPadSystem()) {
+        qDebug() << "isPadSystem";
         if (pSelectItemWgt) {
+            qDebug() << "pSelectItemWgt is not null";
             pSelectItemWgt->setBIsSelect(false);
         }
         auto piw = dynamic_cast<Platform_PlayItemWidget *>(_mouseItem);
         piw->setBIsSelect(true);
         pSelectItemWgt = piw;
     } else {
+        qDebug() << "not isPadSystem";
         auto piw = dynamic_cast<Platform_PlayItemWidget *>(_mouseItem);
         auto menu = ActionFactory::get().playlistContextMenu();
         for (auto act : menu->actions()) {
@@ -1197,10 +1313,12 @@ void Platform_PlaylistWidget::contextMenuEvent(QContextMenuEvent *cme)
     ActionFactory::get().playlistContextMenu()->hide();
     ActionFactory::get().playlistContextMenu()->clear();
 #endif
+    qDebug() << "contextMenuEvent end";
 }
 
 void Platform_PlaylistWidget::showEvent(QShowEvent *se)
 {
+    qDebug() << "showEvent";
     batchUpdateSizeHints();
     adjustSize();
 
@@ -1209,12 +1327,13 @@ void Platform_PlaylistWidget::showEvent(QShowEvent *se)
 
 void Platform_PlaylistWidget::removeItem(int idx)
 {
-    qInfo() << "idx = " << idx;
+    qDebug() << "Removing item at index:" << idx;
     auto item_remove = this->_playlist->item(idx);
     if (item_remove) {
         QWidget *pItem = _playlist->itemWidget(item_remove);
         Platform_PlayItemWidget *pCurItem = dynamic_cast<Platform_PlayItemWidget *>(pItem);
         if (pCurItem == pSelectItemWgt) {
+            qDebug() << "Removing currently selected item";
             pSelectItemWgt = nullptr;            //如果删除的是原来选中的则置空
         }
         item_remove = this->_playlist->takeItem(idx);
@@ -1230,10 +1349,12 @@ void Platform_PlaylistWidget::removeItem(int idx)
     }
 
     if (_playlist->count() != 0 && _playlist->count() != idx) {
+        qDebug() << "setCurItemHovered true";
         QWidget *item = _playlist->itemWidget(_playlist->item(idx));
         Platform_PlayItemWidget *curItem = dynamic_cast<Platform_PlayItemWidget *>(item);
         curItem->setCurItemHovered(true);
     } else if (_playlist->count() != 0 && _playlist->count() == idx) {
+        qDebug() << "setCurItemHovered true";
         QWidget *item = _playlist->itemWidget(_playlist->item(--idx));
         Platform_PlayItemWidget *curItem = dynamic_cast<Platform_PlayItemWidget *>(item);
         curItem->setCurItemHovered(true);
@@ -1241,15 +1362,16 @@ void Platform_PlaylistWidget::removeItem(int idx)
 
     QString s = QString(tr("%1 videos")).arg(_playlist->count());
     _num->setText(s);
+    qDebug() << "Updated playlist count:" << _playlist->count();
 }
 
 void Platform_PlaylistWidget::appendItems()
 {
-    qInfo() << __func__;
-
+    qDebug() << "Appending items to playlist";
     auto items = _engine->playlist().items();
     auto p = items.begin() + this->_playlist->count();
     while (p != items.end()) {
+        qDebug() << "Adding item at index:" << (p - items.begin());
         auto w = new Platform_PlayItemWidget(*p, this->_playlist, p - items.begin(), this);
 
         auto item = new QListWidgetItem;
@@ -1262,58 +1384,69 @@ void Platform_PlaylistWidget::appendItems()
         _closeMapper->setMapping(w, w);
         _activateMapper->setMapping(w, w);
         ++p;
-
     }
     QString s = QString(tr("%1 videos")).arg(_playlist->count());
     _num->setText(s);
+    qDebug() << "Updated playlist count:" << _playlist->count();
     batchUpdateSizeHints();
     updateItemStates();
-//    _playlist->setStyleSheet(styleSheet());
-//    setStyleSheet(styleSheet());
 }
 
 void Platform_PlaylistWidget::slotShowSelectItem(QListWidgetItem *item)
 {
+    qDebug() << "slotShowSelectItem";
     Platform_PlayItemWidget *pWidget = nullptr;
 
     if (item) {
+        qDebug() << "item is not null";
         _playlist->setCurrentItem(item);
         pWidget = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(item));
         if (!pWidget) {
+            qDebug() << "pWidget is null, return";
             return;
         }
     }
 
     if (CompositingManager::get().isPadSystem()) {
+        qDebug() << "isPadSystem";
         pWidget->doDoubleClick();
         if (pSelectItemWgt) {
+            qDebug() << "pSelectItemWgt is not null";
             pSelectItemWgt->setBIsSelect(false);
             pSelectItemWgt = nullptr;
         }
     } else {
+        qDebug() << "is not PadSystem";
         pWidget->setBIsSelect(true);
     }
+    qDebug() << "slotShowSelectItem end";
 }
 
 void Platform_PlaylistWidget::OnItemChanged(QListWidgetItem *current, QListWidgetItem *previous)
 {
+    qDebug() << "OnItemChanged";
     Platform_PlayItemWidget *prevItemWgt = nullptr;
     Platform_PlayItemWidget *curItemWgt = nullptr;
     bool bIsPad = CompositingManager::get().isPadSystem();
 
     if (previous) {
+        qDebug() << "previous is not null";
         prevItemWgt = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(previous));
         if (!bIsPad && prevItemWgt) {
+            qDebug() << "prevItemWgt is not null";
             prevItemWgt->setBIsSelect(false);
         }
     }
 
     if (current) {
+        qDebug() << "current is not null";
         curItemWgt = reinterpret_cast<Platform_PlayItemWidget *>(_playlist->itemWidget(current));
         if (!bIsPad && curItemWgt) {
+            qDebug() << "curItemWgt is not null";
             curItemWgt->setBIsSelect(true);
         }
     }
+    qDebug() << "OnItemChanged end";
 }
 
 void Platform_PlaylistWidget::resetFocusAttribute(bool &atr)
@@ -1323,7 +1456,7 @@ void Platform_PlaylistWidget::resetFocusAttribute(bool &atr)
 
 void Platform_PlaylistWidget::loadPlaylist()
 {
-    qInfo() << __func__;
+    qDebug() << "loadPlaylist";
     _playlist->clear();
 
 
@@ -1345,45 +1478,54 @@ void Platform_PlaylistWidget::loadPlaylist()
 
     batchUpdateSizeHints();
     updateItemStates();
-//    _playlist->setStyleSheet(styleSheet());
     QString s = QString(tr("%1 videos")).arg(_playlist->count());
     _num->setText(s);
-//    setStyleSheet(styleSheet());
+    qDebug() << "loadPlaylist end";
 }
 
 void Platform_PlaylistWidget::batchUpdateSizeHints()
 {
+    qDebug() << "batchUpdateSizeHints";
     if (isVisible()) {
+        qDebug() << "isVisible";
         for (int i = 0; i < this->_playlist->count(); i++) {
             auto item = this->_playlist->item(i);
             auto w = this->_playlist->itemWidget(item);
-            //auto t = w->size();
             item->setSizeHint(w->size());
         }
     }
+    qDebug() << "batchUpdateSizeHints end";
 }
 
 void Platform_PlaylistWidget::endAnimation()
 {
+    qDebug() << "endAnimation";
     if (paOpen != nullptr && paClose != nullptr) {
+        qDebug() << "paOpen and paClose are not null";
         paOpen -> setDuration(0);
         paClose->setDuration(0);
     }
+    qDebug() << "endAnimation end";
 }
 
 bool Platform_PlaylistWidget::isFocusInPlaylist()
 {
+    qDebug() << "isFocusInPlaylist";
     if (m_pClearButton == focusWidget() || _playlist == focusWidget()) {
+        qDebug() << "focusWidget is m_pClearButton or _playlist, return true";
         return true;
     } else {
+        qDebug() << "focusWidget is not m_pClearButton or _playlist, return false";
         return false;
     }
 }
 
 void Platform_PlaylistWidget::togglePopup(bool isShortcut)
 {
+    qDebug() << "Toggling playlist popup, shortcut:" << isShortcut;
     if (paOpen != nullptr || paClose != nullptr) {
-        return ;
+        qDebug() << "Animation in progress, returning";
+        return;
     }
 /**
  * 此处在动画执行前设定好Platform_PlaylistWidget起始位置和终止位置
@@ -1399,6 +1541,7 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
     int toolbox_height = TOOLBOX_HEIGHT;
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        qDebug() << "Using compact mode toolbox height";
         toolbox_height = TOOLBOX_DSIZEMODE_HEIGHT;
     }
 #endif
@@ -1412,9 +1555,13 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
     shrunk.setHeight(0);
     shrunk.moveBottom(fixed.bottom());
 
-    if (_toggling) return;
+    if (_toggling) {
+        qDebug() << "Toggle in progress, returning";
+        return;
+    }
 
     if (_state == State::Opened) {
+        qDebug() << "Closing playlist";
         Q_ASSERT(isVisible());
 
         //Set this judgment to false when the playlist is collapsed
@@ -1428,6 +1575,7 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
         emit stateChange(isShortcut);
         setVisible(!isVisible());
     } else {
+        qDebug() << "Opening playlist";
         _playlist->setAttribute(Qt::WA_TransparentForMouseEvents, true);
         setVisible(!isVisible());
         _toggling = false;  //条件编译误报(cppcheck)
@@ -1436,6 +1584,7 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
         setGeometry(fixed);
         _playlist->setAttribute(Qt::WA_TransparentForMouseEvents, false);
     }
+    qDebug() << "Opening playlist end";
 }
 
 void Platform_PlaylistWidget::paintEvent(QPaintEvent *pe)
@@ -1474,11 +1623,13 @@ bool Platform_PlaylistWidget::eventFilter(QObject *obj, QEvent *event)
         if (event->type() == QEvent::KeyPress) {
             if (static_cast<QKeyEvent *>(event)->key() == Qt::Key_Up ||
                     static_cast<QKeyEvent *>(event)->key() == Qt::Key_Down) {
+                qDebug() << "Ignoring Up/Down keys on clear button";
                 return true;
             }
         }
         switch (event->type()) {
         case QEvent::FocusIn:
+            qDebug() << "Clear button focus in";
             ((Platform_ToolboxProxy *)_mw->toolbox())->setBtnFocusSign(true);
             break;
         case QEvent::FocusOut:
@@ -1494,10 +1645,12 @@ bool Platform_PlaylistWidget::eventFilter(QObject *obj, QEvent *event)
             if (_playlist->count()) {
                 //The judgment here is to prevent the focus from shifting during mouse operation
                 if (!m_bButtonFocusOut) {
+                    qDebug() << "Ignoring focus in during mouse operation";
                     return true;
                 }
                 //焦点切换到播放列表，选中第一个条目
                 if (_playlist->currentRow() != 0) {
+                    qDebug() << "Setting focus to first item";
                     _playlist->setCurrentRow(0);
                     _index = 0;
                     m_bButtonFocusOut = false;
@@ -1509,6 +1662,7 @@ bool Platform_PlaylistWidget::eventFilter(QObject *obj, QEvent *event)
             QKeyEvent *keyPressEv = static_cast<QKeyEvent *>(event);
             if (keyPressEv->key() == Qt::Key_Tab) {
                 //将焦点设置到清空按钮上，实现焦点循环
+                qDebug() << "Tab key pressed, moving focus to clear button";
                 m_pClearButton->setFocus();
                 return true;
             }
