@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -260,16 +260,16 @@ TEST(MainWindow, DBus)
     Platform_MainWindow *w = dApp->getMainWindow();
     Platform_ApplicationAdaptor *appAdaptor = new Platform_ApplicationAdaptor(w);
     DBusUtils utils;
-    QVariant v = Platform_ApplicationAdaptor::redDBusProperty("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
-                                                     "com.deepin.daemon.Audio", "SinkInputs");
+    QVariant v = Platform_ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+                                                     "org.deepin.dde.Audio1", "SinkInputs");
     QVariant v_invalid = Platform_ApplicationAdaptor::redDBusProperty("com.test", "/test", "com.test", "SinkInputs");
     v_invalid = DBusUtils::redDBusProperty("com.test", "/test", "com.test", "SinkInputs");
 
     if (v.isValid()) {
         QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
         for (auto curPath : allSinkInputsList) {
-            QVariant name = Platform_ApplicationAdaptor::redDBusProperty("com.deepin.daemon.Audio", curPath.path(),
-                                                                "com.deepin.daemon.Audio.SinkInput", "Name");
+            QVariant name = Platform_ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", curPath.path(),
+                                                                "org.deepin.dde.Audio1.SinkInput", "Name");
 
             QString strMovie = QObject::tr("Movie");
             if (!name.isValid() || (!name.toString().contains(strMovie, Qt::CaseInsensitive) && !name.toString().contains("deepin-movie", Qt::CaseInsensitive)))
@@ -280,11 +280,11 @@ TEST(MainWindow, DBus)
         }
     }
 
-    QVariant method = Platform_ApplicationAdaptor::redDBusMethod("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
-                                                        "com.deepin.daemon.Audio", "SinkInputs");
+    QVariant method = Platform_ApplicationAdaptor::redDBusMethod("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+                                                        "org.deepin.dde.Audio1", "SinkInputs");
     QVariant method_invalid = Platform_ApplicationAdaptor::redDBusMethod("com.test", "/com/test", "com.test", "SinkInputs");
-    method = DBusUtils::redDBusMethod("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
-                                      "com.deepin.daemon.Audio", "SinkInputs");
+    method = DBusUtils::redDBusMethod("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+                                      "org.deepin.dde.Audio1", "SinkInputs");
     method_invalid = DBusUtils::redDBusMethod("com.test", "/com/test", "com.test", "SinkInputs");
     appAdaptor->Raise();
     appAdaptor->openFile("/data/source/deepin-movie-reborn/movie/demo.mp4");
